@@ -37,13 +37,10 @@
 #include <libgimp/gimptypes.h>
 
 #include <libgimp/gimpbatchprocedure.h>
-#include <libgimp/gimpbrushselect.h>
 #include <libgimp/gimpchannel.h>
 #include <libgimp/gimpdisplay.h>
 #include <libgimp/gimpdrawable.h>
-#include <libgimp/gimpfontselect.h>
 #include <libgimp/gimpgimprc.h>
-#include <libgimp/gimpgradientselect.h>
 #include <libgimp/gimpimage.h>
 #include <libgimp/gimpimagecolorprofile.h>
 #include <libgimp/gimpimagemetadata.h>
@@ -52,19 +49,22 @@
 #include <libgimp/gimplayer.h>
 #include <libgimp/gimplayermask.h>
 #include <libgimp/gimploadprocedure.h>
-#include <libgimp/gimppaletteselect.h>
 #include <libgimp/gimpparamspecs.h>
-#include <libgimp/gimppatternselect.h>
 #include <libgimp/gimppdb.h>
 #include <libgimp/gimpplugin.h>
 #include <libgimp/gimpprocedureconfig.h>
 #include <libgimp/gimpprocedure-params.h>
 #include <libgimp/gimpprogress.h>
+#include <libgimp/gimpresource.h>
 #include <libgimp/gimpsaveprocedure.h>
 #include <libgimp/gimpselection.h>
+#include <libgimp/gimptextlayer.h>
 #include <libgimp/gimpthumbnailprocedure.h>
 #include <libgimp/gimpvectors.h>
 
+/* Resources and their widgets. Order important. */
+#include <libgimp/gimpresourceselect.h>
+
 #include <libgimp/gimp_pdb_headers.h>
 
 #undef __GIMP_H_INSIDE__
