@@ -344,34 +344,34 @@ G_BEGIN_DECLS
   g_value_take_param (gimp_value_array_index (args, n), value)
 
 
-/*  uint8 array  */
+/*  bytes  */
 
-#define GIMP_PROC_ARG_UINT8_ARRAY(procedure, name, nick, blurb, flags) \
+#define GIMP_PROC_ARG_BYTES(procedure, name, nick, blurb, flags) \
   gimp_procedure_add_argument (procedure,\
-                               gimp_param_spec_uint8_array (name, nick, blurb,\
-                               flags))
+                               g_param_spec_boxed (name, nick, blurb,\
+                               G_TYPE_BYTES, flags))
 
-#define GIMP_PROC_AUX_ARG_UINT8_ARRAY(procedure, name, nick, blurb, flags) \
+#define GIMP_PROC_AUX_ARG_BYTES(procedure, name, nick, blurb, flags) \
   gimp_procedure_add_aux_argument (procedure,\
-                                   gimp_param_spec_uint8_array (name, nick, blurb,\
-                                   flags))
+                                   g_param_spec_boxed (name, nick, blurb,\
+                                   G_TYPE_BYTES, flags))
 
-#define GIMP_PROC_VAL_UINT8_ARRAY(procedure, name, nick, blurb, flags) \
+#define GIMP_PROC_VAL_BYTES(procedure, name, nick, blurb, flags) \
   gimp_procedure_add_return_value (procedure,\
-                                   gimp_param_spec_uint8_array (name, nick, blurb,\
-                                   flags))
+                                   g_param_spec_boxed (name, nick, blurb,\
+                                   G_TYPE_BYTES, flags))
 
-#define GIMP_VALUES_GET_UINT8_ARRAY(args, n) \
-  gimp_value_get_uint8_array (gimp_value_array_index (args, n))
+#define GIMP_VALUES_GET_BYTES(args, n) \
+  g_value_get_boxed (gimp_value_array_index (args, n))
 
-#define GIMP_VALUES_DUP_UINT8_ARRAY(args, n) \
-  gimp_value_dup_uint8_array (gimp_value_array_index (args, n))
+#define GIMP_VALUES_DUP_BYTES(args, n) \
+  g_value_dup_boxed (gimp_value_array_index (args, n))
 
-#define GIMP_VALUES_SET_UINT8_ARRAY(args, n, value, length) \
-  gimp_value_set_uint8_array (gimp_value_array_index (args, n), value, length)
+#define GIMP_VALUES_SET_BYTES(args, n, value, length) \
+  g_value_set_boxed (gimp_value_array_index (args, n), value)
 
-#define GIMP_VALUES_TAKE_UINT8_ARRAY(args, n, value, length) \
-  gimp_value_take_uint8_array (gimp_value_array_index (args, n), value, length)
+#define GIMP_VALUES_TAKE_BYTES(args, n, value, length) \
+  g_value_take_boxed (gimp_value_array_index (args, n), value)
 
 
 /*  int32 array  */
@@ -859,6 +859,64 @@ G_BEGIN_DECLS
   g_value_take_object (gimp_value_array_index (args, n), value)
 
 
+/*  Resource  */
+
+#define GIMP_PROC_ARG_BRUSH(procedure, name, nick, blurb, flags)  \
+  gimp_procedure_add_argument (procedure,\
+                               gimp_param_spec_brush (name, nick, blurb,\
+                                                      GIMP_TYPE_BRUSH,\
+                                                      flags))
+#define GIMP_PROC_ARG_FONT(procedure, name, nick, blurb, flags)  \
+  gimp_procedure_add_argument (procedure,\
+                               gimp_param_spec_font (name, nick, blurb,\
+                                                      GIMP_TYPE_FONT,\
+                                                      flags))
+#define GIMP_PROC_ARG_GRADIENT(procedure, name, nick, blurb, flags)  \
+  gimp_procedure_add_argument (procedure,\
+                               gimp_param_spec_gradient (name, nick, blurb,\
+                                                         GIMP_TYPE_GRADIENT,\
+                                                         flags))
+#define GIMP_PROC_ARG_PALETTE(procedure, name, nick, blurb, flags)  \
+  gimp_procedure_add_argument (procedure,\
+                               gimp_param_spec_palette (name, nick, blurb,\
+                                                        GIMP_TYPE_PALETTE,\
+                                                        flags))
+#define GIMP_PROC_ARG_PATTERN(procedure, name, nick, blurb, flags)  \
+  gimp_procedure_add_argument (procedure,\
+                               gimp_param_spec_pattern (name, nick, blurb,\
+                                                        GIMP_TYPE_PATTERN,\
+                                                        flags))
+
+#define GIMP_VALUES_GET_RESOURCE(args, n) \
+  g_value_get_object (gimp_value_array_index (args, n))
+#define GIMP_VALUES_SET_RESOURCE(args, n, value) \
+  g_value_set_object (gimp_value_array_index (args, n), value)
+
+#define GIMP_VALUES_GET_BRUSH(args, n) \
+  g_value_get_object (gimp_value_array_index (args, n))
+#define GIMP_VALUES_SET_BRUSH(args, n, value) \
+  g_value_set_object (gimp_value_array_index (args, n), value)
+
+#define GIMP_VALUES_GET_FONT(args, n) \
+  g_value_get_object (gimp_value_array_index (args, n))
+#define GIMP_VALUES_SET_FONT(args, n, value) \
+  g_value_set_object (gimp_value_array_index (args, n), value)
+
+#define GIMP_VALUES_GET_GRADIENT(args, n) \
+  g_value_get_object (gimp_value_array_index (args, n))
+#define GIMP_VALUES_SET_GRADIENT(args, n, value) \
+  g_value_set_object (gimp_value_array_index (args, n), value)
+
+#define GIMP_VALUES_GET_PALETTE(args, n) \
+  g_value_get_object (gimp_value_array_index (args, n))
+#define GIMP_VALUES_SET_PALETTE(args, n, value) \
+  g_value_set_object (gimp_value_array_index (args, n), value)
+
+#define GIMP_VALUES_GET_PATTERN(args, n) \
+  g_value_get_object (gimp_value_array_index (args, n))
+#define GIMP_VALUES_SET_PATTERN(args, n, value) \
+  g_value_set_object (gimp_value_array_index (args, n), value)
+
 G_END_DECLS
 
 #endif /* __GIMP_PROCEDURE_PARAMS_H__ */
